<?

# COPYRIGHT:
#  
# This software is Copyright (c) 2007 NETWAYS GmbH, Christian Doebler 
#                                <support@netways.de>
# 
# (Except where explicitly superseded by other copyright notices)
# 
# 
# LICENSE:
# 
# This work is made available to you under the terms of Version 2 of
# the GNU General Public License. A copy of that license should have
# been provided with this software, but in any event can be snarfed
# from http://www.fsf.org.
# 
# This work is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301 or visit their web page on the internet at
# http://www.fsf.org.
# 
# 
# CONTRIBUTION SUBMISSION POLICY:
# 
# (The following paragraph is not intended to limit the rights granted
# to you to modify and distribute this software under the terms of
# the GNU General Public License and is only of importance to you if
# you choose to contribute your changes and enhancements to the
# community by submitting them to NETWAYS GmbH.)
# 
# By intentionally submitting any modifications, corrections or
# derivatives to this work, or any other work intended for use with
# this Software, to NETWAYS GmbH, you confirm that
# you are the copyright holder for those contributions and you grant
# NETWAYS GmbH a nonexclusive, worldwide, irrevocable,
# royalty-free, perpetual, license to use, copy, create derivative
# works based on those contributions, and sublicense and distribute
# those contributions and any derivatives thereof.
#
# Nagios and the Nagios logo are registered trademarks of Ethan Galstad.


/**
 * getContent - main function for this module
 *
 * @param		none
 * @return		HTML content
 */
function getContent () {

	$templateContent = new nwTemplate(TEMPLATE_ADD_EDIT);

	// assign labels
	$templateContent->assign('ADD_EDIT_OVERVIEW_LINK', ADD_EDIT_OVERVIEW_LINK);
	$templateContent->assign('HEADING_HOSTS_AND_SERVICES', ADD_EDIT_HEADING_HOSTS_AND_SERVICES);
	$templateContent->assign('HEADING_TIMEZONE', ADD_EDIT_HEADING_TIMEZONE);
	$templateContent->assign('HEADING_PERSONS', ADD_EDIT_HEADING_PERSONS);
	$templateContent->assign('HEADING_NOTIFICATION', ADD_EDIT_HEADING_NOTIFICATION);
	$templateContent->assign('ADD_EDIT_INCLUDE_HOSTS', ADD_EDIT_INCLUDE_HOSTS);
	$templateContent->assign('ADD_EDIT_EXCLUDE_HOSTS', ADD_EDIT_EXCLUDE_HOSTS);
	$templateContent->assign('ADD_EDIT_INCLUDE_SERVICES', ADD_EDIT_INCLUDE_SERVICES);
	$templateContent->assign('ADD_EDIT_EXCLUDE_SERVICES', ADD_EDIT_EXCLUDE_SERVICES);
	$templateContent->assign('ADD_EDIT_TIMEZONE', ADD_EDIT_TIMEZONE);
	$templateContent->assign('ADD_EDIT_OWNER', ADD_EDIT_OWNER);
	$templateContent->assign('ADD_EDIT_NOTIFY_USERS', ADD_EDIT_NOTIFY_USERS);
	$templateContent->assign('ADD_EDIT_NOTIFY_GROUPS', ADD_EDIT_NOTIFY_GROUPS);
	$templateContent->assign('ADD_EDIT_NOTIFY_BY', ADD_EDIT_NOTIFY_BY);
	$templateContent->assign('ADD_EDIT_NOTIFY_ON', ADD_EDIT_NOTIFY_ON);
	$templateContent->assign('ADD_EDIT_SUBMIT', ADD_EDIT_SUBMIT);

	// get info and assign defaults
	$id = (!isset($_GET['id'])) ? ((isset($_POST['id'])) ? $_POST['id'] : null) : $_GET['id'];
	$timezone = null;
	$notify_users = null;
	$notify_groups = null;
	$notify_by = null;
	$owner = null;
	$dbResult = null;

	if (!empty($id)) {

		$id_safe = prepareDBValue($id);

		$templateContent->assign('ID', $id);

		$dbResult = queryDB('select * from notifications where id=\'' . $id_safe . '\'');
		$dbResult = $dbResult[0];

		$templateContent->assign('ACTION', 'update');
		$templateContent->assign('HEADING', ADD_EDIT_HEADING_EDIT);

		$templateContent->assign('INCLUDE_HOSTS', $dbResult['hosts_include']);
		$templateContent->assign('EXCLUDE_HOSTS', $dbResult['hosts_exclude']);

		$templateContent->assign('INCLUDE_SERVICES', $dbResult['services_include']);
		$templateContent->assign('EXCLUDE_SERVICES', $dbResult['services_exclude']);

		// get notification users
		$dbSub = queryDB('select c.username from contacts c
							left join notifications_to_contacts nc on nc.contact_id=c.id
							where nc.notification_id=\'' . $id_safe . '\'
							order by c.username');
		if (is_array($dbSub)) {
			foreach($dbSub as $subRow) {
				$notify_users[] = $subRow['username'];
			}
		}

		// get notification groups
		$query = 'select cg.id from contactgroups cg
					left join notifications_to_contactgroups ncg on cg.id=ncg.contactgroup_id
					where ncg.notification_id=\'' . $id_safe . '\'';
		$dbSub = queryDB($query);
		if (is_array($dbSub)) {
			foreach($dbSub as $subRow) {
				$notify_groups[] = $subRow['id'];
			}
		}

		// get notification methods
		$dbSub = queryDB('select method_id from notifications_to_methods where notification_id=\'' . $id_safe . '\'');
		if (is_array($dbSub)) {
			foreach($dbSub as $subRow) {
				$notify_by[] = $subRow['method_id'];
			}
		}

	} else {

		$templateContent->assign('ACTION', 'add_new');
		$templateContent->assign('HEADING', ADD_EDIT_HEADING_NEW);

	}

	// assign form elements and defaults
	$templateContent->assign('TIMEZONE_SELECT', htmlSelect('timezone', getTimeZone(), $dbResult['timezone_id']));

	if (empty($id) && !empty($_SESSION['user'])) {
		$templateContent->assign('OWNER_SELECT', $_SESSION['user'] . htmlInput('owner', 'hidden', $_SESSION['user']));
	} else {
		$templateContent->assign('OWNER_SELECT', htmlSelect('owner', getContacts(), $dbResult['username']));
	}

	$templateContent->assign('NOTIFY_USERS_SELECT', htmlSelect('notify_users[]', getContacts($dbResult['username']), $notify_users, 'size="5" multiple="multiple"'));
	$templateContent->assign('NOTIFY_GROUPS_SELECT', htmlSelect('notify_groups[]', getContactGroups(), $notify_groups, 'site="5" multiple="multiple"'));

	$templateContent->assign('NOTIFY_BY_SELECT', htmlSelect('notify_by[]', getNotificationMethods(), $notify_by, 'multiple="multiple"', array('', '')));

	$templateContent->assign('CHECKED_NOTIFY_OK', ($dbResult['on_ok'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_WARNING', ($dbResult['on_warning'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_UNKNOWN', ($dbResult['on_unknown'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_HOST_UNREACHABLE', ($dbResult['on_host_unreachable'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_CRITICAL', ($dbResult['on_critical'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_HOST_UP', ($dbResult['on_host_up'] == '1') ? ' checked="checked"' : null);
	$templateContent->assign('CHECKED_NOTIFY_HOST_DOWN', ($dbResult['on_host_down'] == '1') ? ' checked="checked"' : null);

	return $templateContent->getHTML();

}

?>